<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderSndFileFactory</name>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="66"/>
        <source>Sndfile Plugin</source>
        <translation>Sndfile 插件</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="68"/>
        <source>PCM Files</source>
        <translation>PCM 文件</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="136"/>
        <source>About Sndfile Audio Plugin</source>
        <translation>关于 Sndfile 音频插件</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="137"/>
        <source>Qmmp Sndfile Audio Plugin</source>
        <translation>Qmmp Sndfile 音频插件</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="138"/>
        <source>Compiled against</source>
        <translation>编译依赖</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="139"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
